/*
 * Copyright (c) 2001 World Wide Web Consortium,
 * (Massachusetts Institute of Technology, Institut National de
 * Recherche en Informatique et en Automatique, Keio University). All
 * Rights Reserved. This program is distributed under the W3C's Software
 * Intellectual Property License. This program is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY; without even
 * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.
 * See W3C License http://www.w3.org/Consortium/Legal/ for more details.
 */

package org.w3c.dom.contentModel;

import org.w3c.dom.Attr,NodeCM;
import org.w3c.dom.DOMException;

/**
 * This interface extends <code>Attr</code> to provide guided editing of an 
 * XML document.
 * <p>See also the <a href='http://www.w3.org/TR/2001/WD-DOM-Level-3-CMLS-20010419'>Document Object Model (DOM) Level 3 Content Models and Load
and Save Specification</a>.
 */
public interface AttributeCM extends Attr,NodeCM {
    /**
     * returns the corresponding attribute declaration in the content model.
     * @return The attribute declaration corresponding to this attribute
     */
    public CMAttributeDeclaration getAttributeDeclaration();

    /**
     * Returns the notation declaration for the attributes defined of type 
     * NOTATION.
     * @return Returns the notation declaration for this attribute if the 
     *   type is of notation type, null otherwise.
     * @exception DOMException
     *   DOMException
     */
    public CMNotationDeclaration getNotation()
                                             throws DOMException;

}
